(function(portalUtility){

portalUtility.showField = function showField(fieldName){
    $("#"+fieldName).closest("td").find("div.control, div.info").show();
};

portalUtility.hideField = function hideField(fieldName){
    $("#"+fieldName).closest("td").find("div.control, div.info").hide();
};

portalUtility.setFieldReadOnly = function setFieldReadOnly(fieldName){
    $("#"+fieldName).attr("readonly", true);
};

portalUtility.setDropdownDisabled = function setDropdownDisabled(fieldName){
    $("#"+fieldName).prop( "disabled", true );
};

portalUtility.showSection = function showSection(sectionName){
    $("table[data-name='"+sectionName+"']").parent().show();
};

portalUtility.hideSection = function hideSection(sectionName){
    $("table[data-name='"+sectionName+"']").parent().hide();
};

portalUtility.hideTab = function hideTab(tabName){
    $("div[data-name='"+tabName+"']").prev("h2.tab-title").hide();  
    $("div[data-name='"+tabName+"']").hide(); 
};

portalUtility.showTab = function showTab(tabName){
    $("div[data-name='"+tabName+"']").prev("h2.tab-title").show();
    $("div[data-name='"+tabName+"']").show();
};

portalUtility.hideListColumn = function hideListColumn(columnName){
    var list = $(".entity-grid")
    list.on("loaded", function () {
        list.find("th:contains('"+columnName+"')").hide(); 
        list.find("td[data-th='"+columnName+"']").hide(); 
    }); 
};

portalUtility.showListColumn = function showListColumn(columnName){
    var list = $(".entity-grid")
    list.on("loaded", function () {
        list.find("th:contains('"+columnName+"')").show();
        list.find("td[data-th='"+columnName+"']").show();
    }); 
};

portalUtility.clearLookup = function clearLookup(fieldName){
    $("#"+fieldName).siblings("div.input-group-btn").children("button.clearlookupfield").click();
};

portalUtility.clearDateField = function clearDateField(fieldName){
    $("#"+fieldName).val('');
    $("#"+fieldName+"_datepicker_description").val('');
};

portalUtility.setMinDateInput = function setMinDateInput(fieldName, newMinDate){
    $("#"+fieldName).next().data("DateTimePicker").minDate(newMinDate);
};

portalUtility.getSection = function getSection(sectionName){
    return $("fieldset[aria-label='"+sectionName+"']");
};

portalUtility.renameSection = function renameSection(sectionName, newName){
    $("fieldset[aria-label='"+sectionName+"']").children('legend:first').text(newName);
};

portalUtility.getTab = function getTab(tabName){
    return $("div[data-name='"+tabName+"']");
};

portalUtility.changeLabel = function changeLabel(fieldName, labelText){
    $("#"+fieldName+"_label").text(labelText);
};

portalUtility.setLookupFieldValue = function setLookupFieldValue(entitySchema, recordName, recordGuid){
    $("#"+entitySchema+"id_name").attr("value",recordName);
    $("#"+entitySchema+"id").attr("value",recordGuid);
    $("#"+entitySchema+"id_entityname").attr("value",entitySchema);
};

portalUtility.convertLookupToTextValue = function convertLookupToTextValue(fieldName){
    $("#"+fieldName+"_name").addClass("readonly");
    $("#"+fieldName).siblings("div.input-group-btn").hide();

};

portalUtility.setFieldRequired = function setFieldRequired(fieldName, validationMessage) {
    try {
        if ($("#" + fieldName) != undefined) {
            $("#" + fieldName).prop('required', true);
            $("#" + fieldName).closest(".control").prev().addClass("required");
            let errorMessage = validationMessage ?? $("#" + fieldName + "_label").html() + " is a required field.";

            // Create new validator
            var Requiredvalidator = document.createElement('span');
            Requiredvalidator.style.display = "none";
            Requiredvalidator.id = fieldName + "Validator";
            Requiredvalidator.controltovalidate = fieldName;
            Requiredvalidator.errormessage = "<a href='#" + fieldName + "_label'>" + errorMessage + "</a>";
            Requiredvalidator.initialvalue = "";
            Requiredvalidator.evaluationfunction = function () {
                var value = $("#" + fieldName).val();
                if (value == null || value == "") {
                    return false;
                } else {
                    return true;
                }
            };

            // Add the new validator to the page validators array:
            Page_Validators.push(Requiredvalidator);
        }
    }
    catch (error) {
        errorHandler(error);
    }
};

portalUtility.setFieldNotRequired = function setFieldNotRequired(fieldName) {
    //Clean up previous validator <span> if present
    if ($('#ValidationSummaryEntityFormView').length) {
        $('#ValidationSummaryEntityFormView').hide();
    }

    try {
        if ($("#" + fieldName) != undefined) {
            $("#" + fieldName).closest(".control").prev().removeClass("required");
            $("#" + fieldName).prop('required', false);

            for (i = 0; i < Page_Validators.length; i++) {
                if (Page_Validators[i
                ].id == fieldName + "Validator") {
                    Page_Validators.splice(i,1);
                }
            }
        }
    }
    catch (error) {
        errorHandler(error);
    }
};

portalUtility.setIsLoading = function setIsLoading(showLoader){
    if (showLoader)
        $("#loader").show();
    else $("#loader").hide();
};

portalUtility.setupCurrencyInput = function setupCurrencyInput(fieldId){
    $("#"+fieldId).attr("type","number");
    $("#"+fieldId).attr("min","0");
    $("#"+fieldId).attr("step","any");
    $("#"+fieldId).keypress(function(event){
        var  ASCIICode = event.which ? event.which : event.keyCode;
        if(ASCIICode >= 48 && ASCIICode <=57){      // check if the enterd value is a number or a character
            return true;
        } else{
            return false;
        }
    });
};

portalUtility.clearSelection = function clearSelection(id) {
    var fullId = id + "_i";
    // Check if the "+1" button exists and if it does, click it
    var toggleButton = document.querySelector("#" + fullId + " .msos-selecteditems-toggle");
    if (toggleButton) {
        toggleButton.click();
    }

    // Now proceed with clearing the items
    var selectedItems = document.querySelectorAll("#" + fullId + " .msos-selected-display-item");

    selectedItems.forEach(function(item) {
        item.classList.remove("msos-visible");
        item.removeAttribute("aria-label");
        item.removeAttribute("data-value");
        item.innerHTML = "";
    });

    var selectedOptions = document.querySelectorAll("#" + fullId + " .msos-option.msos-option-selected");

    selectedOptions.forEach(function(option) {
        option.classList.remove("msos-option-selected");
        option.setAttribute("aria-selected", "false");

        var checkbox = option.querySelector("input[type='checkbox']");
        checkbox.checked = false;
    });

    // Uncheck the "Select all" checkbox
    var selectAllCheckbox = document.querySelector("#" + fullId + " #" + id + "_selectAll");
    if (selectAllCheckbox) {
        selectAllCheckbox.checked = false;
    }
}

// Checks for a multiselect value 
portalUtility.checkDataValue = function checkDataValue(attributeValue, targetValue) {    
    var items = document.querySelectorAll('li[name*="' + attributeValue + '"]');    
    for (var i = 0; i < items.length; i++) {      
      var value = items[i].getAttribute('data-value');
      if (value === targetValue) {
        return true;
      }
    }
    return false;
  }
 
 // Deselects all but one multiselect value
portalUtility.deselectAllExcept = function deselectAllExcept(attributeValue, targetDataValue) {
    var items = document.querySelectorAll('li[name*="' + attributeValue + '"]');
    var checkboxes = document.querySelectorAll('input[type="checkbox"][name="' + attributeValue + '"]');
    for (var j = 0; j < checkboxes.length; j++) {
        checkboxes[j].checked = false;
    }
    for (var i = 0; i < items.length; i++) {
        var dataValue = items[i].getAttribute('data-value');
        if (dataValue !== targetDataValue) {
            items[i].remove();
        } else {
            var checkbox = items[i].querySelector('input[type="checkbox"]');
            if (checkbox) {
                checkbox.checked = true;
            }
        }
    }
} 


})(window.portalUtility = window.portalUtility || {})
